# OSDNClient::ProjectApi

All URIs are relative to *https://osdn.jp/api/v0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_news**](ProjectApi.md#create_news) | **POST** /news | 
[**create_news_0**](ProjectApi.md#create_news_0) | **POST** /project/{id_or_name}/news | 
[**create_package**](ProjectApi.md#create_package) | **POST** /project/{id_or_name}/frs | 
[**create_release**](ProjectApi.md#create_release) | **POST** /project/{id_or_name}/frs/{package_id} | 
[**create_release_file**](ProjectApi.md#create_release_file) | **POST** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**delete_news**](ProjectApi.md#delete_news) | **DELETE** /news/{news_id} | 
[**delete_news_0**](ProjectApi.md#delete_news_0) | **DELETE** /project/{id_or_name}/news/{news_id} | 
[**delete_package**](ProjectApi.md#delete_package) | **DELETE** /project/{id_or_name}/frs/{package_id} | 
[**delete_release**](ProjectApi.md#delete_release) | **DELETE** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**delete_release_file**](ProjectApi.md#delete_release_file) | **DELETE** /project/{id_or_name}/frs/{package_id}/{release_id}/{file_id} | 
[**draft_release**](ProjectApi.md#draft_release) | **GET** /project/{id_or_name}/frs/{package_id}/draft | 
[**get_news**](ProjectApi.md#get_news) | **GET** /news/{news_id} | 
[**get_news_0**](ProjectApi.md#get_news_0) | **GET** /project/{id_or_name}/news/{news_id} | 
[**get_package**](ProjectApi.md#get_package) | **GET** /project/{id_or_name}/frs/{package_id} | 
[**get_project**](ProjectApi.md#get_project) | **GET** /project/{id_or_name} | 
[**get_release**](ProjectApi.md#get_release) | **GET** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**get_release_file**](ProjectApi.md#get_release_file) | **GET** /project/{id_or_name}/frs/{package_id}/{release_id}/{file_id} | 
[**list_news**](ProjectApi.md#list_news) | **GET** /news | 
[**list_news_0**](ProjectApi.md#list_news_0) | **GET** /project/{id_or_name}/news | 
[**list_packages**](ProjectApi.md#list_packages) | **GET** /project/{id_or_name}/frs | 
[**update_news**](ProjectApi.md#update_news) | **PATCH** /news/{news_id} | 
[**update_news_0**](ProjectApi.md#update_news_0) | **PATCH** /project/{id_or_name}/news/{news_id} | 
[**update_package**](ProjectApi.md#update_package) | **PATCH** /project/{id_or_name}/frs/{package_id} | 
[**update_release**](ProjectApi.md#update_release) | **PATCH** /project/{id_or_name}/frs/{package_id}/{release_id} | 
[**update_release_file**](ProjectApi.md#update_release_file) | **PATCH** /project/{id_or_name}/frs/{package_id}/{release_id}/{file_id} | 


# **create_news**
> String create_news(title, body, group_id)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

title = "title_example" # String | news title

body = "body_example" # String | news body in OSDN Wiki format.

group_id = 56 # Integer | group_id the news created in


begin
  result = api_instance.create_news(title, body, group_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->create_news: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **title** | **String**| news title | 
 **body** | **String**| news body in OSDN Wiki format. | 
 **group_id** | **Integer**| group_id the news created in | 

### Return type

**String**

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_news_0**
> String create_news_0(id_or_name, title, body)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

title = "title_example" # String | news title

body = "body_example" # String | news body in OSDN Wiki format.


begin
  result = api_instance.create_news_0(id_or_name, title, body)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->create_news_0: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **title** | **String**| news title | 
 **body** | **String**| news body in OSDN Wiki format. | 

### Return type

**String**

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_package**
> Package create_package(id_or_name, name, opts)



Create a package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

name = "name_example" # String | package name

opts = { 
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.create_package(id_or_name, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->create_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **name** | **String**| package name | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**Package**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_release**
> Release create_release(id_or_name, package_id, name, opts)



Create new release in specified package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

name = "name_example" # String | Release name

opts = { 
  visibility: "visibility_example", # String | visibility status (public, hidden or private)
  time: "time_example", # String | Release datetime. If you set future time, the release hide until specified time.
  release_note: "release_note_example", # String | Release note body text.
  change_log: "change_log_example" # String | Changelog body text.
}

begin
  result = api_instance.create_release(id_or_name, package_id, name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->create_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **name** | **String**| Release name | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 
 **time** | **String**| Release datetime. If you set future time, the release hide until specified time. | [optional] 
 **release_note** | **String**| Release note body text. | [optional] 
 **change_log** | **String**| Changelog body text. | [optional] 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **create_release_file**
> RelFile create_release_file(id_or_name, package_id, release_id, file, opts)



Create new file in target release.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file = File.new("/path/to/file.txt") # File | Upload file in \"multipart/form-data\".

opts = { 
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.create_release_file(id_or_name, package_id, release_id, file, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->create_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file** | **File**| Upload file in \&quot;multipart/form-data\&quot;. | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**RelFile**](RelFile.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: Not defined



# **delete_news**
> delete_news(news_id)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

news_id = 56 # Integer | 


begin
  api_instance.delete_news(news_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->delete_news: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **news_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_news_0**
> delete_news_0(id_or_name, news_id)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

news_id = 56 # Integer | 


begin
  api_instance.delete_news_0(id_or_name, news_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->delete_news_0: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **news_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_package**
> delete_package(id_or_name, package_id)



Delete taret package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 


begin
  api_instance.delete_package(id_or_name, package_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->delete_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_release**
> delete_release(id_or_name, package_id, release_id)



Delete target release.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 


begin
  api_instance.delete_release(id_or_name, package_id, release_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->delete_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **delete_release_file**
> delete_release_file(id_or_name, package_id, release_id, file_id)



Delete target file.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file_id = 56 # Integer | 


begin
  api_instance.delete_release_file(id_or_name, package_id, release_id, file_id)
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->delete_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file_id** | **Integer**|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **draft_release**
> Release draft_release(id_or_name, package_id)



Get release draft in specified package. If draft is not exist, it will be created automatically.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 


begin
  result = api_instance.draft_release(id_or_name, package_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->draft_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_news**
> News get_news(news_id)



Get single news object.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

news_id = 56 # Integer | 


begin
  result = api_instance.get_news(news_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->get_news: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **news_id** | **Integer**|  | 

### Return type

[**News**](News.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_news_0**
> News get_news_0(id_or_name, news_id)



Get single news object.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

news_id = 56 # Integer | 


begin
  result = api_instance.get_news_0(id_or_name, news_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->get_news_0: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **news_id** | **Integer**|  | 

### Return type

[**News**](News.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_package**
> Package get_package(id_or_name, package_id)



Get specified package info and release list of the package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 


begin
  result = api_instance.get_package(id_or_name, package_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->get_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 

### Return type

[**Package**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_project**
> Group get_project(id_or_name)



Get project info.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.get_project(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->get_project: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Group**](Group.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_release**
> Release get_release(id_or_name, package_id, release_id)



Get specified release info and file list of the release.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 


begin
  result = api_instance.get_release(id_or_name, package_id, release_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->get_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **get_release_file**
> RelFile get_release_file(id_or_name, package_id, release_id, file_id)



Get single file object.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file_id = 56 # Integer | 


begin
  result = api_instance.get_release_file(id_or_name, package_id, release_id, file_id)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->get_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file_id** | **Integer**|  | 

### Return type

[**RelFile**](RelFile.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_news**
> Array&lt;News&gt; list_news(opts)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

opts = { 
  group_id: 56 # Integer | filter by group ID
}

begin
  result = api_instance.list_news(opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->list_news: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **Integer**| filter by group ID | [optional] 

### Return type

[**Array&lt;News&gt;**](News.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_news_0**
> Array&lt;News&gt; list_news_0(id_or_name)



Get news list of spscified project.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.list_news_0(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->list_news_0: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Array&lt;News&gt;**](News.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **list_packages**
> Array&lt;Package&gt; list_packages(id_or_name)



Get package list of specified project.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name


begin
  result = api_instance.list_packages(id_or_name)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->list_packages: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 

### Return type

[**Array&lt;Package&gt;**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_news**
> News update_news(news_id, opts)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

news_id = 56 # Integer | 

opts = { 
  title: "title_example", # String | news title
  body: "body_example" # String | news body in OSDN Wiki format.
}

begin
  result = api_instance.update_news(news_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->update_news: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **news_id** | **Integer**|  | 
 **title** | **String**| news title | [optional] 
 **body** | **String**| news body in OSDN Wiki format. | [optional] 

### Return type

[**News**](News.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_news_0**
> News update_news_0(news_id, id_or_name, opts)



### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

news_id = 56 # Integer | 

id_or_name = "id_or_name_example" # String | numeric project id or project name

opts = { 
  title: "title_example", # String | news title
  body: "body_example" # String | news body in OSDN Wiki format.
}

begin
  result = api_instance.update_news_0(news_id, id_or_name, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->update_news_0: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **news_id** | **Integer**|  | 
 **id_or_name** | **String**| numeric project id or project name | 
 **title** | **String**| news title | [optional] 
 **body** | **String**| news body in OSDN Wiki format. | [optional] 

### Return type

[**News**](News.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_package**
> Package update_package(id_or_name, package_id, opts)



Update tagret package.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

opts = { 
  name: "name_example", # String | package name
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.update_package(id_or_name, package_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->update_package: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **name** | **String**| package name | [optional] 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**Package**](Package.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_release**
> Release update_release(id_or_name, package_id, release_id, opts)



Update target release. (Note: If you update draft release, the release will be public automatically.) 

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

opts = { 
  visibility: "visibility_example", # String | visibility status (public, hidden or private)
  name: "name_example", # String | Release name
  time: "time_example", # String | Release datetime. If you set future time, the release hide until specified time.
  move_to_package_id: 56 # Integer | If this parameter is specified, the release move to another package.
}

begin
  result = api_instance.update_release(id_or_name, package_id, release_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->update_release: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 
 **name** | **String**| Release name | [optional] 
 **time** | **String**| Release datetime. If you set future time, the release hide until specified time. | [optional] 
 **move_to_package_id** | **Integer**| If this parameter is specified, the release move to another package. | [optional] 

### Return type

[**Release**](Release.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



# **update_release_file**
> RelFile update_release_file(id_or_name, package_id, release_id, file_id, opts)



Change visibility of target file.

### Example
```ruby
# load the gem
require 'osdn-client'
# setup authorization
OSDNClient.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2-code
  config.access_token = 'YOUR ACCESS TOKEN'

  # Configure OAuth2 access token for authorization: oauth2-implicit
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OSDNClient::ProjectApi.new

id_or_name = "id_or_name_example" # String | numeric project id or project name

package_id = 56 # Integer | 

release_id = 56 # Integer | 

file_id = 56 # Integer | 

opts = { 
  visibility: "visibility_example" # String | visibility status (public, hidden or private)
}

begin
  result = api_instance.update_release_file(id_or_name, package_id, release_id, file_id, opts)
  p result
rescue OSDNClient::ApiError => e
  puts "Exception when calling ProjectApi->update_release_file: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id_or_name** | **String**| numeric project id or project name | 
 **package_id** | **Integer**|  | 
 **release_id** | **Integer**|  | 
 **file_id** | **Integer**|  | 
 **visibility** | **String**| visibility status (public, hidden or private) | [optional] 

### Return type

[**RelFile**](RelFile.md)

### Authorization

[oauth2-code](../README.md#oauth2-code), [oauth2-implicit](../README.md#oauth2-implicit)

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: Not defined



